==> vue-rate-2.8.0.tgz: package/lib/pc.js <==
import { renderless, api } from "@dft-vue-2-opentiny/vue-renderless/rate/vue";
import { defineComponent, props, setup as _setup } from "@dft-vue-2-opentiny/vue-common";
import { iconStarActive, iconStarDisable, iconSmile, iconFrown, iconMeh } from "@dft-vue-2-opentiny/vue-icon";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["modelValue", "radio", "lowThreshold", "highThreshold", "max", "colors", "voidColor", "disabledVoidColor", "iconClasses", "voidIconClass", "disabledVoidIconClass", "disabled", "allowHalf", "showText", "showScore", "textColor", "texts", "textOnBottom", "space", "size", "scoreTemplate"]),
  components: {
    IconStarActive: iconStarActive(),
    IconStarDisable: iconStarDisable(),
    IconSmile: iconSmile(),
    IconFrown: iconFrown(),
    IconMeh: iconMeh()
  },
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-rate",
    attrs: {
      "tabindex": "0"
    },
    on: {
      "keydown": _vm.handelKey
    }
  }, [_vm._l(_vm.max, function(item) {
    return _c("span", {
      key: item,
      staticClass: "tiny-rate__star",
      style: {
        width: _vm.space,
        cursor: _vm.disabled ? "auto" : "pointer"
      },
      on: {
        "mousemove": function mousemove($event) {
          return _vm.setCurrentValue({
            item,
            event: $event
          });
        },
        "mouseleave": _vm.resetCurrentValue,
        "click": function click($event) {
          return _vm.selectValue(item);
        }
      }
    }, [_c(_vm.state.classes[item - 1], {
      tag: "component",
      class: ["tiny-svg-size", "tiny-rate__icon", {
        hover: _vm.state.hoverIndex === item
      }, _vm.disabled ? "disabled" : "", _vm.showDecimalIcon(item) ? "ratehalf" : ""],
      style: _vm.getIconStyle(item)
    }), _vm.showDecimalIcon(item) ? _c(_vm.state.decimalIconClass, {
      tag: "component",
      staticClass: "tiny-svg-size tiny-rate__decimal",
      style: _vm.state.decimalStyle
    }) : _vm._e(), _vm.textOnBottom && !_vm.radio ? _c("div", {
      staticClass: "tiny-rate__bottom-text",
      style: {
        color: _vm.textColor
      }
    }, [_vm._v(" " + _vm._s(_vm.texts[item - 1]) + " ")]) : _vm._e(), _vm.textOnBottom && _vm.radio ? _c("div", {
      staticClass: "tiny-rate__bottom-text",
      style: _vm.getTextStyle()
    }, [_vm._v(" " + _vm._s(_vm.texts[item - 1]) + " ")]) : _vm._e()], 1);
  }), !_vm.textOnBottom && _vm.showText || _vm.showScore ? _c("span", {
    staticClass: "tiny-rate__text",
    style: {
      color: _vm.textColor
    }
  }, [_vm._v(_vm._s(_vm.state.text))]) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-rate-2.22.0.tgz: package/lib/pc.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/rate/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconStarActive, iconStarDisable, iconSmile, iconFrown, iconMeh } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  props: [].concat(props, ["modelValue", "radio", "lowThreshold", "highThreshold", "max", "colors", "voidColor", "disabledVoidColor", "iconClasses", "voidIconClass", "disabledVoidIconClass", "disabled", "allowHalf", "showText", "showScore", "textColor", "texts", "textOnBottom", "space", "size", "scoreTemplate"]),
  components: {
    IconStarActive: iconStarActive(),
    IconStarDisable: iconStarDisable(),
    IconSmile: iconSmile(),
    IconFrown: iconFrown(),
    IconMeh: iconMeh()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-rate",
    attrs: {
      "tabindex": "0"
    },
    on: {
      "keydown": _vm.handelKey
    }
  }, [_vm._l(_vm.max, function(item) {
    return _c("span", {
      key: item,
      staticClass: "tiny-rate__star",
      style: {
        width: _vm.space,
        cursor: _vm.disabled ? "auto" : "pointer"
      },
      on: {
        "mousemove": function mousemove($event) {
          return _vm.setCurrentValue({
            item,
            event: $event
          });
        },
        "mouseleave": _vm.resetCurrentValue,
        "click": function click($event) {
          return _vm.selectValue(item);
        }
      }
    }, [_c(_vm.state.classes[item - 1], {
      tag: "component",
      class: ["tiny-svg-size", "tiny-rate__icon", {
        hover: _vm.state.hoverIndex === item
      }, _vm.disabled ? "disabled" : "", _vm.showDecimalIcon(item) ? "ratehalf" : ""],
      style: _vm.getIconStyle(item)
    }), _vm.showDecimalIcon(item) ? _c(_vm.state.decimalIconClass, {
      tag: "component",
      staticClass: "tiny-svg-size tiny-rate__decimal",
      style: _vm.state.decimalStyle
    }) : _vm._e(), _vm.textOnBottom && !_vm.radio ? _c("div", {
      staticClass: "tiny-rate__bottom-text",
      style: {
        color: _vm.textColor
      }
    }, [_vm._v(" " + _vm._s(_vm.texts[item - 1]) + " ")]) : _vm._e(), _vm.textOnBottom && _vm.radio ? _c("div", {
      staticClass: "tiny-rate__bottom-text",
      style: _vm.getTextStyle()
    }, [_vm._v(" " + _vm._s(_vm.texts[item - 1]) + " ")]) : _vm._e()], 1);
  }), !_vm.textOnBottom && _vm.showText || _vm.showScore ? _c("span", {
    staticClass: "tiny-rate__text",
    style: {
      color: _vm.textColor
    }
  }, [_vm._v(_vm._s(_vm.state.text))]) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
